#!/usr/bin/env node
"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
var _a;
Object.defineProperty(exports, "__esModule", { value: true });
var console_1 = require("console");
var meow_1 = __importDefault(require("meow"));
var fs_1 = __importDefault(require("fs"));
var path_1 = __importDefault(require("path"));
var index_1 = require("./index");
var helpMessage = "\n\uD83D\uDC3C\uFE0F .- hello friend, here's what I have. Thanks to use soldoc.\n\nUsage\n    $ soldoc [options] <output-folder> <file(s)>\n\nOptions\n    --help, -h  To get help\n    --output -o The output type [html/pdf/gitbook/docsify] default: html\n    --ignore -i An array of files to ignore\n    --tests -t Path to the tests folder. Default: ./test\n    --testsExtension -te Regex to filter test files. Default: .(spec|test).[jt]s\n    --baseLocation -bl Base location, used to render test files link. Default: repository url\n\nExamples\n    $ soldoc docs/ contracts/Sample.sol\n    $ soldoc docs/ contracts/\n    $ soldoc --tests ./mytests docs/ Sample.sol\n    $ soldoc --output pdf docs/ Sample.sol\n    $ soldoc --output gitbook --ignore Migrations.sol docs/ Sample.sol\n";
var defaultBaseLocation = (_a = JSON.parse(fs_1.default.readFileSync(path_1.default.join(process.cwd(), 'package.json')).toString()).repository) === null || _a === void 0 ? void 0 : _a.url.replace('git+', '');
var cli = meow_1.default(helpMessage, {
    flags: {
        baseLocation: {
            alias: 'bl',
            default: defaultBaseLocation,
            type: 'string',
        },
        ignore: {
            alias: 'i',
            type: 'string',
        },
        output: {
            alias: 'o',
            default: 'html',
            type: 'string',
        },
        tests: {
            alias: 't',
            default: 'test',
            type: 'string',
        },
        testsExtension: {
            alias: 'te',
            default: '\.(spec|test)\.[jt]s',
            type: 'string',
        },
    },
});
var terminalConsole = new console_1.Console(process.stdout, process.stderr);
var main = function () {
    if (cli.input.length !== 2) {
        terminalConsole.error('You must be doing something wrong. There\'s a 🐼️ available to help you, '
            + 'just write \'soldoc --help\'.\r\n\r\n\t🐼 ️🐼️ are really cool! Aren\'t they?');
        return 1;
    }
    // pdf generation is a bit slower
    if (cli.flags.output === 'pdf') {
        terminalConsole.log('Wait...pdf, might take a moment! 🐼️ is working on it...');
    }
    var ignoreList = [];
    if (cli.flags.ignore && cli.flags.ignore.length > 0) {
        var commaPosition = cli.flags.ignore.indexOf(',');
        if (commaPosition >= -1) {
            ignoreList = cli.flags.ignore.split(',');
        }
    }
    return index_1.generate(cli.flags.output, ignoreList, String(cli.input[0]), String(cli.input[1]), cli.flags.tests, cli.flags.testsExtension, cli.flags.baseLocation);
};
main();
//# sourceMappingURL=cli.js.map