"use strict";
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
var fs_1 = __importDefault(require("fs"));
var path_1 = __importDefault(require("path"));
var solidity_parser_antlr_1 = __importDefault(require("@hq20/solidity-parser-antlr"));
function extendParamsAstWithNatspec(node) {
    if (node.parameters === null) {
        return null;
    }
    return node.parameters.map(function (parameter) { return (__assign(__assign({}, parameter), { natspec: parameter.name === null ||
            node.natspec === null ||
            node.natspec.params === undefined
            ? ''
            : node.natspec.params[parameter.name] })); });
}
function extendReturnParamsAstWithNatspec(node) {
    if (node.returnParameters === null || node.returnParameters === undefined) {
        return null;
    }
    return node.returnParameters.map(function (parameter) { return (__assign(__assign({}, parameter), { natspec: node.natspec === null
            ? ''
            : node.natspec.return })); });
}
function extendsVisibility(node) {
    return {
        external: node.visibility === 'external',
        internal: node.visibility === 'internal',
        private: node.visibility === 'private',
        public: node.visibility === 'public',
    };
}
function extendsStateMutability(node) {
    return {
        payable: node.stateMutability === 'payable',
        pure: node.stateMutability === 'pure',
        view: node.stateMutability === 'view',
    };
}
/**
 * Prepare for the given file.
 * @param {string} solidityFilePath the file's path to be parsed
 */
function parseSingleSolidityFile(solidityFilePath, testComments, baseLocation) {
    var folder = path_1.default.join(__dirname, '../');
    var input = fs_1.default.readFileSync(solidityFilePath).toString();
    var ast = solidity_parser_antlr_1.default.parse(input);
    var data = {
        events: [],
        functions: [],
        structs: [],
        variables: [],
    };
    // we can safely do this, because the contract definition always happenes before methods!
    var currentContractName;
    // visit all the methods and add the commands to it
    solidity_parser_antlr_1.default.visit(ast, {
        ContractDefinition: function (node) {
            var _a;
            data = __assign({ contract: node, testFile: (_a = testComments.get(node.name)) === null || _a === void 0 ? void 0 : _a.filter(function (commentsTestNode) { return commentsTestNode.name === '#'; }) }, data);
            currentContractName = node.name;
        },
        EventDefinition: function (node) {
            data.events.push({
                ast: node,
                parameters: extendParamsAstWithNatspec(node),
                returnParameters: extendReturnParamsAstWithNatspec(node),
            });
        },
        FunctionDefinition: function (node) {
            var _a;
            if ((node.natspec !== null && node.natspec.dev !== 'soldoc-ignore' ||
                node.natspec === null)) {
                if (node.isConstructor) {
                    data = __assign({ constructor: {
                            ast: node,
                            parameters: extendParamsAstWithNatspec(node),
                            returnParameters: extendReturnParamsAstWithNatspec(node),
                        } }, data);
                }
                else {
                    var tests = (_a = testComments.get(currentContractName)) === null || _a === void 0 ? void 0 : _a.filter(function (commentsTestNode) { return commentsTestNode.name === node.name; }).map(function (commentsTestNode) { return commentsTestNode = __assign(__assign({}, commentsTestNode), { filePath: path_1.default.join(baseLocation, commentsTestNode.filePath) }); });
                    data.functions.push({
                        ast: node,
                        hasTests: tests !== undefined,
                        parameters: extendParamsAstWithNatspec(node),
                        returnParameters: extendReturnParamsAstWithNatspec(node),
                        stateMutability: extendsStateMutability(node),
                        tests: tests,
                        visibility: extendsVisibility(node),
                    });
                }
            }
        },
        InheritanceSpecifier: function (node) {
            var currentInheritance = data.inheritance;
            if (currentInheritance !== undefined) {
                currentInheritance.push(node.baseName);
            }
            else {
                currentInheritance = [node.baseName];
            }
            data = __assign({ inheritance: currentInheritance }, data);
        },
        StateVariableDeclaration: function (node) {
            data.variables.push({
                ast: __assign(__assign({}, node), { variable: node.variables[0] }),
                visibility: extendsVisibility(node),
            });
        },
    });
    var name = ast.children.filter(function (child) { return child.type === 'ContractDefinition'; })[0].name;
    var filename = path_1.default.parse(solidityFilePath).name;
    return {
        data: data,
        filename: filename,
        folder: folder,
        name: name,
        path: solidityFilePath,
    };
}
exports.parseSingleSolidityFile = parseSingleSolidityFile;
//# sourceMappingURL=solidity.js.map